==> lxqt-runner_1.1.0.orig.tar.xz: lxqt-runner-1.1.0/translations/lxqt-runner_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Innstillinger for programstarter</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Vis på:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Vis historikk først</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Lagre/vis historikk</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Obs&lt;/b&gt;: Størrelsen på widgeter er begrenset til 2/3 av skrivebordets høyde og bredde.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Vis liste med:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> element(er)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Tastatursnarevei:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Øverste kant på skjermen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Midt på skjermen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Skjerm som har fokus</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Alltid på skjerm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Nullstill</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Programstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>Konfigurer</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>Slett historikk</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="374"/>
        <source>Show/hide runner dialog</source>
        <translation>Vis/skjul programstarter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Historikk</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Kopier utregnet resultat til utklippstavlen</translation>
    </message>
</context>
</TS>

==> lxqt-runner_1.2.0+dfsg.orig.tar.xz: lxqt-runner-1.2.0/translations/lxqt-runner_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Innstillinger for programstarter</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Vis på:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Vis historikk først</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Lagre/vis historikk</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Obs&lt;/b&gt;: Størrelsen på widgeter er begrenset til 2/3 av skrivebordets høyde og bredde.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Vis liste med:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> element(er)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="80"/>
        <source>Clear input on launching</source>
        <translation type="unfinished">Tøm inndata ved start</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="97"/>
        <source>Shortcut:</source>
        <translation>Tastatursnarevei:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Øverste kant på skjermen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Midt på skjermen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Skjerm som har fokus</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Alltid på skjerm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Nullstill</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Programstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>Konfigurer</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>Slett historikk</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="408"/>
        <source>Show/hide runner dialog</source>
        <translation>Vis/skjul programstarter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Historikk</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Kopier utregnet resultat til utklippstavlen</translation>
    </message>
</context>
</TS>
